/******************************************************************************
 * 
 * Copyright 2012 - 2013 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/

package com.vektorsoft.demux.core.app;

import java.util.Map;

/**
 * <p>
 *  This interface defined methods used by classes who want to be aware of changes of data 
 * inside model. Within DEMUX Framework, it is typically used to track progress when controller 
 * performs some long running action.
 * </p>
 *
 * @author Vladimir Djurovic
 */
public interface ModelChangeAware {
    
    /**
     * Add new listener.
     * 
     * @param listener listener to add
     */
    void addModelChangeListener(ModelChangeListener listener);
    
    /**
     * Remove specified listener.
     * 
     * @param listener listener to add
     */
    void removeModelChangeListener(ModelChangeListener listener);
    
    /**
     * Notify listeners that model data is changed.
     * 
     * @param data changed data
     */
    void notifyDataChanged(Map<String, Object> data);

}
