/******************************************************************************
 * 
 * Copyright 2012 - 2013 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/


package com.vektorsoft.demux.core.extension;

import com.vektorsoft.demux.core.annotations.DMXModelData;
import java.lang.reflect.Field;
import java.util.HashMap;
import java.util.Map;

/**
 * Abstract implementation of {@link DMXExtensionCallback}. It provides implementation of methods
 * to set/get model data, and allows clients to use {@code DMXModel} annotations for model data.
 *
 * @author Vladimir Djurovic
 */
public abstract  class DMXAbstractCallback implements DMXExtensionCallback {
    
    /**
     * Map of model fields is implementing class.
     */
    private Map<String, Field> fieldMap;
    
    /**
     * Map of model data.
     */
    private Map<String, Object> dataMap;
    
    /**
     * Creates new instance.
     */
    public DMXAbstractCallback(){
        dataMap = new HashMap<String, Object>();
    }
    

    @Override
    public final Map<String, Object> getCallbackData() {
        if(fieldMap == null){
            fieldMap = new HashMap<String, Field>();
            Field[] fields = getClass().getDeclaredFields();
            for(Field field : fields){
                DMXModelData modelData = field.getAnnotation(DMXModelData.class);
                if(modelData != null){
                    String id = modelData.id();
                    if(id == null || id.isEmpty()){
                        id = field.getName();
                    }
                    field.setAccessible(true);
                    fieldMap.put(id, field);
                }
                
            }
        }
        dataMap.clear();
        for(Map.Entry<String, Field> entry : fieldMap.entrySet()){
            try {
                dataMap.put(entry.getKey(), entry.getValue().get(this));
            } catch(IllegalAccessException iae){
                System.err.println("Could not access field " + entry.getKey());
            }
            
        }
        return dataMap;
    }

    @Override
    public final void setDataValuesFromModel(Map<String, Object> dmap) {
        for(Map.Entry<String, Object> entry : dmap.entrySet()){
            Field field = fieldMap.get(entry.getKey());
            if(field != null){
                try {
                    field.set(this, entry.getValue());
                } catch(IllegalAccessException ex){
                    System.err.println("Could not access field " + entry.getKey());
                }
                
            }
        }
    }

    
}
