/******************************************************************************
 * 
 * Copyright 2012 - 2014 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/

package com.vektorsoft.demux.core.extension;

import java.util.List;
import java.util.Properties;

/**
 * <p>
 * This interfaces defines methods which must be implemented by classes used to configure extensions 
 * of a bundle. Implementations of this class must be in fragment bundle, whose host is the bundle 
 * intended for extension.
 * </p>
 *
 * @author Vladimir Djurovic
 */
public interface DMXExtensionConfig {

    /**
     * Returns a list of extension callbacks in current bundle.
     * 
     * @return  list of callbacks
     */
    List<DMXExtensionCallback> getExtensionCallbacks();
    
    /**
     * Returns configuration properties intended to customize bundle activator startup. These properties
     * are different from bundle to bundle.
     * 
     * @return configuration properties
     */
    Properties getActivatorConfig();
}
