/******************************************************************************
 * 
 * Copyright 2012 - 2013 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/

package com.vektorsoft.demux.desktop.gui;

import com.vektorsoft.demux.core.mva.DMXEventRegistrationHandler;

/**
 * Provides method definitions to interact with main window toolbar.
 *
 * @param <T> platform specific toolbar type (ie. javafx.scene.control.ToolBar for Java FX or 
 *              org.eclipse.swt.widgets.toolbar for SWT)
 * @author Vladimir Djurovic
 */
public interface DMXToolbarService<T> {

    /**
     * Add toolbar to main window toolbar.
     * 
     * @param toolbar toolbar to add
     */
    void addToolbar(T toolbar);
    
    /**
     * Insert toolbar at specified index in main window toolbar. Toolbars to 
     * the right of specified index will be shifted.
     * 
     * @param index index to insert toolbar at
     * @param toolbar toolbar to add
     */
    void insertToolbarAtIndex(int index, T toolbar);
    
    /**
     * Sets style for the main toolbar.
     * 
     * @param style style to set
     */
    void setToolbarStyle(String style);
    
    /**
     * Registers event handler on toolbar component with specified ID.
     * 
     * @param id component ID
     * @param handler event handler
     */
    void registerEventHandlerForId(String id, DMXEventRegistrationHandler handler);
}
