/******************************************************************************
 * 
 * Copyright 2012 - 2014 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/
package com.vektorsoft.demux.desktop.jfx;

import com.vektorsoft.demux.core.mva.DMXAdapter;
import com.vektorsoft.demux.core.mva.DMXDefaultAdapter;
import com.vektorsoft.demux.core.resources.DMXResourceManager;
import com.vektorsoft.demux.core.resources.ResourceHandlerType;
import com.vektorsoft.demux.core.resources.impl.DefaultResourceManager;
import com.vektorsoft.demux.core.resources.impl.DefaultResourceHandler;
import com.vektorsoft.demux.desktop.jfx.app.gui.JFXMenuServiceImpl;
import com.vektorsoft.demux.desktop.jfx.app.JFXViewManager;
import com.vektorsoft.demux.desktop.jfx.app.gui.JFXToolbarServiceImpl;
import com.vektorsoft.demux.desktop.gui.DMXMenuService;
import com.vektorsoft.demux.desktop.gui.DMXToolbarService;
import java.lang.reflect.Field;
import javafx.stage.Stage;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;

/**
 * Customizer for tracking window service.
 *
 * @author Vladimir Djurovic
 */
public class WindowServiceCustomizer implements ServiceTrackerCustomizer<Object, Object> {
    
    /** Name of the field that holds JavaFX stage variable. */
    private static final String FIELD_NAME = "stage";

    /**
     * Bundle context.
     */
    private final BundleContext context;

    /**
     * Create new instance.
     *
     * @param context bundle context
     */
    public WindowServiceCustomizer(BundleContext context) {
        this.context = context;
    }

    @Override
    public Object addingService(ServiceReference<Object> sr) {
        Object svc = context.getService(sr);
        // we use reflection to set correct fields. This is due to classloaders clash
        // when OSGI runtime is started from JavaFX application
        try {
            DMXResourceManager manager = new DefaultResourceManager();
            DMXDefaultAdapter adapter = new DMXDefaultAdapter(manager);
            // get value of JavaFX Stage
            Field field = svc.getClass().getDeclaredField(FIELD_NAME);
            field.setAccessible(true);

         
            // register menu service
            DMXMenuService menuService = new JFXMenuServiceImpl((Stage) field.get(svc), adapter);
            context.registerService(DMXMenuService.class, menuService, null);
            // register toolbar service
            DMXToolbarService ts = new JFXToolbarServiceImpl((Stage) field.get(svc));
            context.registerService(DMXToolbarService.class, ts, null);
            
            JFXViewManager viewManager = new JFXViewManager((Stage) field.get(svc), adapter);
            viewManager.setMenuService(menuService);
            viewManager.setToolbarService(ts);
            adapter.setViewManager(viewManager);
            
            context.registerService(DMXAdapter.class, adapter, null);
            
            field.setAccessible(false);
            
            DefaultResourceHandler handler = adapter.getResourceManager().getResourceHandler(ResourceHandlerType.RESOURCE_BUNDLE);
            handler.loadResourceBundle("bundles.messages", getClass().getClassLoader());

        } catch (IllegalAccessException | NoSuchFieldException ex) {
            throw new RuntimeException(ex);
        }

        return svc;
    }

    @Override
    public void modifiedService(ServiceReference<Object> sr, Object t) {
        // do nothing
    }

    @Override
    public void removedService(ServiceReference<Object> sr, Object t) {
        // do nothing
    }
}
