/******************************************************************************
 * 
 * Copyright 2012 - 2014 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/


package com.vektorsoft.demux.desktop.jfx.gui;

import com.vektorsoft.demux.core.mva.DMXAdapter;
import com.vektorsoft.demux.core.mva.DMXEventRegistrationHandler;
import javafx.event.Event;
import javafx.event.EventHandler;
import javafx.event.EventType;

/**
 * Generic event handler for JavaFX platform. This class also implements {@link DMXEventRegistrationHandler} interface, so 
 * it can be automatically assigned to components which require event handling.
 *
 * @param <T> type of event handler by this class
 * @author Vladimir Djurovic
 */
public abstract class  JFXEventHandler<T extends Event> implements EventHandler<T>, DMXEventRegistrationHandler<EventHandler<T>> {
    
    /** 
     * Adapter instance.
     */
    protected final DMXAdapter adapter;
    
     /**
     * IDs of components to which this handler will be registered.
     */
    private String[] componentIds;
    
    /**
     * Event type to handle.
     */
    private final EventType eventType;
    
    /**
     * Creates new instance.
     * 
     * @param adapter adapter instance
     * @param type  event type
     */
    public JFXEventHandler(DMXAdapter adapter, EventType type){
        this.adapter = adapter;
        this.eventType = type;
    }

    /**
     * Sets component IDs.
     * 
     * @param ids  component IDs
     */
    public final void setComponentIds(String... ids) {
        this.componentIds = ids;
    }

    @Override
    public final String[] getComponentIds() {
        return componentIds;
    }

    @Override
    public final EventHandler<T> getEventHandler() {
        return this;
    }

    /**
     * Returns event type for this handler.
     * 
     * @return event type
     */
    public EventType getEventType() {
        return eventType;
    }


}
