/******************************************************************************
 * 
 * Copyright 2012 - 2013 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/

package com.vektorsoft.demux.desktop.jfx.main.impl;

import com.vektorsoft.demux.desktop.jfx.main.svc.JFXWindowService;
import java.net.URL;
import javafx.application.Platform;
import javafx.scene.image.Image;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.VBox;
import javafx.stage.Stage;

/**
 * Implementation of {@link JFXWindowService} for use in JavaFX application.
 * Provides methods to interact with main JavaFX stage (application window).
 *
 * @author Vladimir Djurovic
 */
public class JFXWindowServiceImpl implements JFXWindowService {

    /**
     * Main application window.
     */
    private Stage stage;

    /**
     * Creates new instance of this class.
     *
     * @param stage main window
     */
    public JFXWindowServiceImpl(Stage stage) {
        this.stage = stage;
        stage.getIcons().add(new Image(getClass().getResourceAsStream("/dmx-icon-16x16.png")));
        stage.getIcons().add(new Image(getClass().getResourceAsStream("/dmx-icon-32x32.png")));
        stage.getIcons().add(new Image(getClass().getResourceAsStream("/dmx-icon-64x64.png")));

        init();
    }

    /**
     * Initializes main window. This method is executed on JavaFX platform thread.
     */
    private void init() {
        Platform.runLater(new Runnable() {
            @Override
            public void run() {
                // make containers for menu and toolbars
                VBox topContainer = new VBox();
                BorderPane bp = (BorderPane) stage.getScene().getRoot();
                bp.setTop(topContainer);
            }
        });
    }

    @Override
    public void setTitle(String title) {
        stage.setTitle(title);
    }

    @Override
    public String getTitle() {
        return stage.getTitle();
    }

    @Override
    public void setWindowIcons(URL... urls) {
        stage.getIcons().clear();
        for (URL url : urls) {
            stage.getIcons().add(new Image(url.toExternalForm()));
        }
    }
}
